"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const FontAwesome_1 = __importDefault(require("./components/FontAwesome"));
const object_1 = require("./helpers/object");
function TableHeader({ tableHeaders, sortedProp, onSortChange, classes, components: { TableHead, TableRow, TableCell } }) {
    const headings = [];
    for (let i = 0; i < tableHeaders.length; i += 1) {
        const thClass = (0, object_1.makeClasses)({
            'thead-th': true,
            sortable: tableHeaders[i].sortable === true
        });
        const thProps = {
            key: `th-${i}`,
            onClick: tableHeaders[i].sortable === true
                ? () => onSortChange(tableHeaders[i].prop)
                : undefined,
            className: (0, object_1.makeClasses)(thClass, classes === null || classes === void 0 ? void 0 : classes.theadCol)
        };
        let sortIcon = 'sort';
        let sortIconRender = null;
        if (tableHeaders[i].sortable === true) {
            if (sortedProp.prop && sortedProp.prop === tableHeaders[i].prop) {
                if (sortedProp.isAscending) {
                    sortIcon = 'sort-asc';
                }
                else {
                    sortIcon = 'sort-desc';
                }
            }
            sortIconRender = react_1.default.createElement(FontAwesome_1.default, { icon: sortIcon, additionalClass: "fa-fw" });
        }
        const headerCell = tableHeaders[i].headerCell;
        let rendered;
        if (headerCell) {
            rendered = headerCell(sortIconRender, sortedProp);
        }
        else {
            rendered = (react_1.default.createElement(react_1.default.Fragment, null,
                tableHeaders[i].title,
                react_1.default.createElement("span", null, sortIconRender)));
        }
        headings.push(react_1.default.createElement(TableCell, Object.assign({}, thProps), rendered));
    }
    return (react_1.default.createElement(TableHead, { className: (0, object_1.makeClasses)('thead', classes === null || classes === void 0 ? void 0 : classes.thead) },
        react_1.default.createElement(TableRow, { className: (0, object_1.makeClasses)('thead-tr', classes === null || classes === void 0 ? void 0 : classes.theadRow) }, headings)));
}
exports.default = TableHeader;
