import React from 'react';
import { makeClasses } from './helpers/object';
export default function TableBody({ tableHeaders, labels, data, classes, components: { TableBody, TableRow, TableCell }, onRowClick }) {
    const body = [];
    const dataLength = data.length;
    if (dataLength !== 0) {
        for (let i = 0; i < dataLength; i += 1) {
            body.push(React.createElement(BodyRow, { key: `row-${i}`, classes: classes, components: {
                    TableRow,
                    TableCell
                }, tableHeaders: tableHeaders, data: data, onClick: onRowClick, rowIdx: i }));
        }
    }
    else {
        body.push(React.createElement(TableRow, { key: `row-zero-length`, className: "tbody-tr" },
            React.createElement(TableCell, { className: "tbody-td", colSpan: tableHeaders.length }, (labels === null || labels === void 0 ? void 0 : labels.noResults) || 'No results to be shown.')));
    }
    return (React.createElement(TableBody, { className: makeClasses('tbody', classes === null || classes === void 0 ? void 0 : classes.tbody) }, body));
}
function BodyRow({ tableHeaders, data, rowIdx, classes, components, onClick }) {
    const row = [];
    for (let i = 0; i < tableHeaders.length; i += 1) {
        const { cell, cellProps = {} } = tableHeaders[i];
        let value = '';
        if (cell === undefined) {
            value = data[rowIdx][tableHeaders[i].prop];
        }
        else {
            value = cell(data[rowIdx]);
        }
        row.push(React.createElement(components.TableCell, { key: `col-${rowIdx}${i}`, className: makeClasses('tbody-td', classes === null || classes === void 0 ? void 0 : classes.tbodyCol, typeof cellProps.className === 'function'
                ? cellProps.className(data[rowIdx])
                : cellProps.className), style: typeof cellProps.style === 'function'
                ? cellProps.style(data[rowIdx])
                : cellProps.style }, value));
    }
    function onRowClick() {
        if (typeof onClick === 'function') {
            onClick(data[rowIdx]);
        }
    }
    return (React.createElement(components.TableRow, { className: makeClasses('tbody-tr', classes === null || classes === void 0 ? void 0 : classes.tbodyRow), onClick: onRowClick }, row));
}
